pub struct ReplyKeyboardRemove {
pub remove_keyboard: bool,
pub selective: Option<bool>,
}Expand description
Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup).
Fields
remove_keyboard: boolselective: Option<bool>Trait Implementations
Sourceimpl Debug for ReplyKeyboardRemove
impl Debug for ReplyKeyboardRemove
Sourceimpl<'de> Deserialize<'de> for ReplyKeyboardRemove
impl<'de> Deserialize<'de> for ReplyKeyboardRemove
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ReplyKeyboardRemove> for ReplyMarkup
impl From<ReplyKeyboardRemove> for ReplyMarkup
Sourcefn from(f: ReplyKeyboardRemove) -> Self
fn from(f: ReplyKeyboardRemove) -> Self
Converts to this type from the input type.